@@ -564,6 +564,17 @@ namespace stan {
     };
     extern boost::phoenix::function<set_fun_type_named> set_fun_type_named_f;
 
+    // called from: term_grammar
+    struct set_array_expr_type : public phoenix_functor_senary {
+      void operator()(expression& e,
+                      array_expr& array_expr,
+                      const var_origin& var_origin,
+                      bool& pass,
+                      const variable_map& var_map,
+                      std::ostream& error_msgs) const;
+    };
+    extern boost::phoenix::function<set_array_expr_type> set_array_expr_type_f;
+
     // called from: term_grammar
     struct exponentiation_expr : public phoenix_functor_quinary {
       void operator()(expression& expr1, const expression& expr2,
@@ -691,7 +702,7 @@ namespace stan {
       bool operator()(const nil& /*e*/) const;
       bool operator()(const int_literal& /*x*/) const;
       bool operator()(const double_literal& /*x*/) const;
-      bool operator()(const array_literal& x) const;
+      bool operator()(const array_expr& x) const;
       bool operator()(const variable& x) const;
       bool operator()(const integrate_ode& x) const;
       bool operator()(const integrate_ode_control& x) const;
@@ -807,6 +818,11 @@ namespace stan {
     };
     extern boost::phoenix::function<validate_in_loop> validate_in_loop_f;
 
+    struct non_void_expression : public phoenix_functor_ternary {
+      void operator()(const expression& e, bool& pass,
+                      std::ostream& error_msgs) const;
+    };
+    extern boost::phoenix::function<non_void_expression> non_void_expression_f;
   }
 }
 #endif
