@@ -1,29 +1,35 @@
 #ifndef STAN_MCMC_HMC_STATIC_ADAPT_UNIT_E_STATIC_HMC_HPP
 #define STAN_MCMC_HMC_STATIC_ADAPT_UNIT_E_STATIC_HMC_HPP
 
-#include <stan/mcmc/stepsize_adapter.hpp>
+#include <stan/interface_callbacks/writer/base_writer.hpp>
 #include <stan/mcmc/hmc/static/unit_e_static_hmc.hpp>
+#include <stan/mcmc/stepsize_adapter.hpp>
 
 namespace stan {
-
   namespace mcmc {
-
-    // Hamiltonian Monte Carlo on a
-    // Euclidean manifold with unit metric,
-    // static integration time,
-    // and adaptive stepsize
-    template <typename Model, class BaseRNG>
+    /**
+     * Hamiltonian Monte Carlo implementation using the endpoint
+     * of trajectories with a static integration time with a
+     * Gaussian-Euclidean disintegration and unit metric and
+     * adaptive step size
+     */
+    template <class Model, class BaseRNG>
     class adapt_unit_e_static_hmc : public unit_e_static_hmc<Model, BaseRNG>,
                                     public stepsize_adapter {
     public:
-      adapt_unit_e_static_hmc(Model &model, BaseRNG& rng,
-                              std::ostream* o, std::ostream* e)
-        : unit_e_static_hmc<Model, BaseRNG>(model, rng, o, e) { }
+      adapt_unit_e_static_hmc(const Model& model, BaseRNG& rng)
+        : unit_e_static_hmc<Model, BaseRNG>(model, rng) { }
 
       ~adapt_unit_e_static_hmc() { }
 
-      sample transition(sample& init_sample) {
-        sample s = unit_e_static_hmc<Model, BaseRNG>::transition(init_sample);
+      sample
+      transition(sample& init_sample,
+                 interface_callbacks::writer::base_writer& info_writer,
+                 interface_callbacks::writer::base_writer& error_writer) {
+        sample s
+          = unit_e_static_hmc<Model, BaseRNG>::transition(init_sample,
+                                                          info_writer,
+                                                          error_writer);
 
         if (this->adapt_flag_) {
           this->stepsize_adaptation_.learn_stepsize(this->nom_epsilon_,
@@ -41,7 +47,5 @@ namespace stan {
     };
 
   }  // mcmc
-
 }  // stan
-
 #endif
