@@ -9,33 +9,29 @@ namespace stan {
 
     class valued_argument: public argument {
     public:
-      virtual void print(std::ostream* s, const int depth,
-                         const std::string prefix) {
-        if (!s)
-          return;
-
+      virtual void print(interface_callbacks::writer::base_writer& w,
+                         const int depth,
+                         const std::string& prefix) {
         std::string indent(compute_indent(depth), ' ');
 
-        *s << prefix << indent << _name << " = " << print_value();
+        std::string message = prefix + indent + _name + " = " + print_value();
+
         if (is_default())
-          *s << " (Default)";
-        *s << std::endl;
+          message +=" (Default)";
+        w(message);
       }
 
-      virtual void print_help(std::ostream* s, const int depth,
+      virtual void print_help(interface_callbacks::writer::base_writer& w,
+                              const int depth,
                               const bool recurse = false) {
-        if (!s)
-          return;
-
         std::string indent(indent_width * depth, ' ');
         std::string subindent(indent_width, ' ');
 
-        *s << indent << _name << "=<" << _value_type << ">" << std::endl;
-        *s << indent << subindent << _description << std::endl;
-        *s << indent << subindent << "Valid values:"
-           << print_valid() << std::endl;
-        *s << indent << subindent << "Defaults to " << _default << std::endl;
-        *s << std::endl;
+        w(indent + _name + "=<" + _value_type + ">");
+        w(indent + subindent + _description);
+        w(indent + subindent + "Valid values:" + print_valid());
+        w(indent + subindent + "Defaults to " + _default);
+        w();
       }
 
       virtual std::string print_value() = 0;
