@@ -3,9 +3,9 @@
 
 #include <stan/interface_callbacks/writer/base_writer.hpp>
 #include <stan/mcmc/base_mcmc.hpp>
-#include <stan/math/prim/mat/fun/Eigen.hpp>
 #include <stan/services/arguments/categorical_argument.hpp>
 #include <stan/services/arguments/singleton_argument.hpp>
+#include <Eigen/Dense>
 #include <ostream>
 
 namespace stan {
