@@ -2,7 +2,7 @@
 #define STAN_VARIATIONAL_NORMAL_FULLRANK_HPP
 
 #include <stan/math/prim/mat.hpp>
-#include <stan/model/util.hpp>
+#include <stan/model/gradient.hpp>
 #include <stan/variational/base_family.hpp>
 #include <algorithm>
 #include <ostream>
