@@ -15,9 +15,8 @@ namespace stan {
     qr_Q(const Eigen::Matrix<fvar<T>, Eigen::Dynamic, Eigen::Dynamic>& m) {
       typedef Eigen::Matrix<fvar<T>, Eigen::Dynamic, Eigen::Dynamic>
         matrix_fwd_t;
-      stan::math::check_nonzero_size("qr_Q", "m", m);
-      stan::math::check_greater_or_equal("qr_Q", "m.rows()", m.rows(),
-                                         m.cols());
+      check_nonzero_size("qr_Q", "m", m);
+      check_greater_or_equal("qr_Q", "m.rows()", m.rows(), m.cols());
       Eigen::HouseholderQR< matrix_fwd_t > qr(m.rows(), m.cols());
       qr.compute(m);
       matrix_fwd_t Q = qr.householderQ();
@@ -26,6 +25,7 @@ namespace stan {
           Q.col(i) *= -1.0;
       return Q;
     }
+
   }
 }
 #endif
