@@ -17,14 +17,14 @@ namespace stan {
     }
 
     template <typename T>
-    inline fvar<T> atan2(const double x1, const fvar<T>& x2) {
+    inline fvar<T> atan2(double x1, const fvar<T>& x2) {
       using std::atan2;
       return fvar<T>(atan2(x1, x2.val_),
                      (-x1 * x2.d_) / (square(x1) + square(x2.val_)));
     }
 
     template <typename T>
-    inline fvar<T> atan2(const fvar<T>& x1, const double x2) {
+    inline fvar<T> atan2(const fvar<T>& x1, double x2) {
       using std::atan2;
       return fvar<T>(atan2(x1.val_, x2),
                      (x1.d_ * x2) / (square(x2) + square(x1.val_)));
