@@ -2,6 +2,7 @@
 #define STAN_MATH_PRIM_MAT_FUN_MULTIPLY_LOWER_TRI_SELF_TRANSPOSE_HPP
 
 #include <stan/math/prim/mat/fun/typedefs.hpp>
+#include <stan/math/prim/scal/fun/square.hpp>
 
 namespace stan {
   namespace math {
@@ -17,25 +18,21 @@ namespace stan {
     inline matrix_d
     multiply_lower_tri_self_transpose(const matrix_d& L) {
       int K = L.rows();
-      int J = L.cols();
-      int k;
-      matrix_d LLt(K, K);
-      matrix_d Lt = L.transpose();
-
       if (K == 0)
-        return matrix_d(0, 0);
+        return L;
       if (K == 1) {
         matrix_d result(1, 1);
-        result(0, 0) = L(0, 0) * L(0, 0);
+        result(0) = square(L(0));  // first elt, so don't need double idx
         return result;
       }
-
+      int J = L.cols();
+      matrix_d LLt(K, K);
+      matrix_d Lt = L.transpose();
       for (int m = 0; m < K; ++m) {
-        k = (J < m + 1) ? J : m + 1;
+        int k = (J < m + 1) ? J : m + 1;
         LLt(m, m) = Lt.col(m).head(k).squaredNorm();
-        for (int n = (m + 1); n < K; ++n) {
+        for (int n = (m + 1); n < K; ++n)
           LLt(n, m) = LLt(m, n) = Lt.col(m).head(k).dot(Lt.col(n).head(k));
-        }
       }
       return LLt;
     }
