@@ -31,11 +31,13 @@ namespace stan {
        \end{cases}
        \f]
      *
-     * @param x Specified value.
-     * @return Natural log of one minus <code>x</code>.
+     * @param[in] x Argument.
+     * @return Natural log of one minus the argument.
+     * @throw std::domain_error If the argument is greater than 1.
+     * @throw std::overflow_error If the computation overflows.
      */
-    inline double log1m(const double x) {
-      return log1p(-x);
+    inline double log1m(double x) {
+      return stan::math::log1p(-x);
     }
 
   }
