@@ -9,15 +9,14 @@
 #include <stan/math/prim/scal/err/check_not_nan.hpp>
 #include <stan/math/prim/scal/err/check_positive_finite.hpp>
 #include <stan/math/prim/scal/fun/constants.hpp>
+#include <stan/math/prim/scal/fun/is_inf.hpp>
 #include <stan/math/prim/scal/meta/include_summand.hpp>
 #include <stan/math/prim/scal/fun/value_of.hpp>
 #include <boost/random/normal_distribution.hpp>
-#include <boost/math/special_functions/fpclassify.hpp>
 #include <boost/random/variate_generator.hpp>
 #include <cmath>
 
 namespace stan {
-
   namespace math {
 
     template <typename T_y, typename T_loc, typename T_scale,
@@ -25,19 +24,12 @@ namespace stan {
     typename return_type<T_y, T_loc, T_scale, T_inv_scale>::type
     exp_mod_normal_cdf(const T_y& y, const T_loc& mu, const T_scale& sigma,
                        const T_inv_scale& lambda) {
-      static const char* function("stan::math::exp_mod_normal_cdf");
+      static const char* function("exp_mod_normal_cdf");
       typedef typename stan::partials_return_type<T_y, T_loc, T_scale,
                                                   T_inv_scale>::type
         T_partials_return;
 
-      using stan::math::check_positive_finite;
-      using stan::math::check_finite;
-      using stan::math::check_not_nan;
-      using stan::math::check_consistent_sizes;
-      using stan::math::value_of;
-
       T_partials_return cdf(1.0);
-      // check if any vectors are zero length
       if (!(stan::length(y)
             && stan::length(mu)
             && stan::length(sigma)
@@ -59,7 +51,6 @@ namespace stan {
       OperandsAndPartials<T_y, T_loc, T_scale, T_inv_scale>
         operands_and_partials(y, mu, sigma, lambda);
 
-      using stan::math::SQRT_2;
       using std::exp;
 
       VectorView<const T_y> y_vec(y);
@@ -67,9 +58,9 @@ namespace stan {
       VectorView<const T_scale> sigma_vec(sigma);
       VectorView<const T_inv_scale> lambda_vec(lambda);
       size_t N = max_size(y, mu, sigma, lambda);
-      const double sqrt_pi = std::sqrt(stan::math::pi());
+      const double sqrt_pi = std::sqrt(pi());
       for (size_t n = 0; n < N; n++) {
-        if (boost::math::isinf(y_vec[n])) {
+        if (is_inf(y_vec[n])) {
           if (y_vec[n] < 0.0)
             return operands_and_partials.value(0.0);
         }
@@ -136,12 +127,9 @@ namespace stan {
         for (size_t n = 0; n < stan::length(lambda); ++n)
           operands_and_partials.d_x4[n] *= cdf;
       }
-
       return operands_and_partials.value(cdf);
     }
+
   }
 }
 #endif
-
-
-
