@@ -20,7 +20,6 @@
 #include <cmath>
 
 namespace stan {
-
   namespace math {
 
     /**
@@ -52,19 +51,14 @@ namespace stan {
     template <bool propto, typename T_y, typename T_inv_scale>
     typename return_type<T_y, T_inv_scale>::type
     exponential_log(const T_y& y, const T_inv_scale& beta) {
-      static const char* function("stan::math::exponential_log");
+      static const char* function("exponential_log");
       typedef typename stan::partials_return_type<T_y, T_inv_scale>::type
         T_partials_return;
 
-      // check if any vectors are zero length
       if (!(stan::length(y)
             && stan::length(beta)))
         return 0.0;
 
-      using stan::math::check_positive_finite;
-      using stan::math::check_not_nan;
-      using stan::math::check_consistent_sizes;
-      using stan::math::value_of;
       using std::log;
 
       T_partials_return logp(0.0);
@@ -74,8 +68,6 @@ namespace stan {
                              "Random variable", y,
                              "Inverse scale parameter", beta);
 
-
-      // set up template expressions wrapping scalars into vector views
       VectorView<const T_y> y_vec(y);
       VectorView<const T_inv_scale> beta_vec(beta);
       size_t N = max_size(y, beta);
@@ -111,7 +103,7 @@ namespace stan {
     exponential_log(const T_y& y, const T_inv_scale& beta) {
       return exponential_log<false>(y, beta);
     }
+
   }
 }
-
 #endif
