@@ -16,19 +16,16 @@
 #include <boost/random/variate_generator.hpp>
 
 namespace stan {
-
   namespace math {
 
     template <class RNG>
     inline double
-    exponential_rng(const double beta,
+    exponential_rng(double beta,
                     RNG& rng) {
       using boost::variate_generator;
       using boost::exponential_distribution;
 
-      static const char* function("stan::math::exponential_rng");
-
-      using stan::math::check_positive_finite;
+      static const char* function("exponential_rng");
 
       check_positive_finite(function, "Inverse scale parameter", beta);
 
@@ -36,7 +33,7 @@ namespace stan {
         exp_rng(rng, exponential_distribution<>(beta));
       return exp_rng();
     }
+
   }
 }
-
 #endif
