@@ -27,19 +27,11 @@ namespace stan {
       typedef typename stan::partials_return_type<T_y, T_scale, T_shape>::type
         T_partials_return;
 
-      // Size checks
       if ( !( stan::length(y) && stan::length(y_min) && stan::length(alpha) ) )
         return 0.0;
 
-      // Check errors
-      static const char* function("stan::math::pareto_ccdf_log");
+      static const char* function("pareto_ccdf_log");
 
-      using stan::math::check_positive_finite;
-      using stan::math::check_not_nan;
-      using stan::math::check_greater_or_equal;
-      using stan::math::check_consistent_sizes;
-      using stan::math::check_nonnegative;
-      using stan::math::value_of;
       using std::log;
       using std::exp;
 
@@ -54,7 +46,6 @@ namespace stan {
                              "Scale parameter", y_min,
                              "Shape parameter", alpha);
 
-      // Wrap arguments in vectors
       VectorView<const T_y> y_vec(y);
       VectorView<const T_scale> y_min_vec(y_min);
       VectorView<const T_shape> alpha_vec(alpha);
@@ -65,22 +56,18 @@ namespace stan {
 
       // Explicit return for extreme values
       // The gradients are technically ill-defined, but treated as zero
-
       for (size_t i = 0; i < stan::length(y); i++) {
         if (value_of(y_vec[i]) < value_of(y_min_vec[i]))
           return operands_and_partials.value(0.0);
       }
 
-      // Compute vectorized cdf_log and its gradients
-
       for (size_t n = 0; n < N; n++) {
         // Explicit results for extreme values
         // The gradients are technically ill-defined, but treated as zero
         if (value_of(y_vec[n]) == std::numeric_limits<double>::infinity()) {
-          return operands_and_partials.value(stan::math::negative_infinity());
+          return operands_and_partials.value(negative_infinity());
         }
 
-        // Pull out values
         const T_partials_return log_dbl = log(value_of(y_min_vec[n])
                                               / value_of(y_vec[n]));
         const T_partials_return y_min_inv_dbl = 1.0 / value_of(y_min_vec[n]);
@@ -96,9 +83,9 @@ namespace stan {
         if (!is_constant_struct<T_shape>::value)
           operands_and_partials.d_x3[n] += log_dbl;
       }
-
       return operands_and_partials.value(P);
     }
+
   }
 }
 #endif
