@@ -11,6 +11,7 @@
 #include <stan/math/prim/scal/fun/constants.hpp>
 #include <stan/math/prim/scal/fun/multiply_log.hpp>
 #include <stan/math/prim/scal/fun/gamma_q.hpp>
+#include <stan/math/prim/scal/fun/lgamma.hpp>
 #include <stan/math/prim/scal/fun/value_of.hpp>
 #include <boost/random/poisson_distribution.hpp>
 #include <boost/random/variate_generator.hpp>
@@ -42,8 +43,6 @@ namespace stan {
       VectorView<const T_rate> lambda_vec(lambda);
       size_t size = max_size(n, lambda);
 
-      using boost::math::gamma_q;
-      using boost::math::lgamma;
       using std::log;
       using std::exp;
 
