@@ -34,7 +34,7 @@ namespace stan {
      * @param b Second value.
      * @return True if first variable's value is greater than second value.
      */
-    inline bool operator>(const var& a, const double b) {
+    inline bool operator>(const var& a, double b) {
       return a.val() > b;
     }
 
@@ -46,7 +46,7 @@ namespace stan {
      * @param b Second variable.
      * @return True if first value is greater than second variable's value.
      */
-    inline bool operator>(const double a, const var& b) {
+    inline bool operator>(double a, const var& b) {
       return a > b.val();
     }
 
