@@ -13,12 +13,12 @@ namespace stan {
     /**
      * Converts argument to an automatic differentiation variable.
      *
-     * Returns a stan::math::var variable with the input value.
+     * Returns a var variable with the input value.
      *
      * @param[in] m A Matrix with scalars
      * @return A Matrix with automatic differentiation variables
      */
-    inline matrix_v to_var(const stan::math::matrix_d& m) {
+    inline matrix_v to_var(const matrix_d& m) {
       matrix_v m_v(m.rows(), m.cols());
       for (int j = 0; j < m.cols(); ++j)
         for (int i = 0; i < m.rows(); ++i)
@@ -28,7 +28,7 @@ namespace stan {
     /**
      * Converts argument to an automatic differentiation variable.
      *
-     * Returns a stan::math::var variable with the input value.
+     * Returns a var variable with the input value.
      *
      * @param[in] m A Matrix with automatic differentiation variables.
      * @return A Matrix with automatic differentiation variables.
@@ -39,13 +39,13 @@ namespace stan {
     /**
      * Converts argument to an automatic differentiation variable.
      *
-     * Returns a stan::math::var variable with the input value.
+     * Returns a var variable with the input value.
      *
      * @param[in] v A Vector of scalars
      * @return A Vector of automatic differentiation variables with
      *   values of v
      */
-    inline vector_v to_var(const stan::math::vector_d& v) {
+    inline vector_v to_var(const vector_d& v) {
       vector_v v_v(v.size());
       for (int i = 0; i < v.size(); ++i)
         v_v[i] = v[i];
@@ -54,7 +54,7 @@ namespace stan {
     /**
      * Converts argument to an automatic differentiation variable.
      *
-     * Returns a stan::math::var variable with the input value.
+     * Returns a var variable with the input value.
      *
      * @param[in] v A Vector of automatic differentiation variables
      * @return A Vector of automatic differentiation variables with
@@ -66,13 +66,13 @@ namespace stan {
     /**
      * Converts argument to an automatic differentiation variable.
      *
-     * Returns a stan::math::var variable with the input value.
+     * Returns a var variable with the input value.
      *
      * @param[in] rv A row vector of scalars
      * @return A row vector of automatic differentation variables with
      *   values of rv.
      */
-    inline row_vector_v to_var(const stan::math::row_vector_d& rv) {
+    inline row_vector_v to_var(const row_vector_d& rv) {
       row_vector_v rv_v(rv.size());
       for (int i = 0; i < rv.size(); ++i)
         rv_v[i] = rv[i];
@@ -81,7 +81,7 @@ namespace stan {
     /**
      * Converts argument to an automatic differentiation variable.
      *
-     * Returns a stan::math::var variable with the input value.
+     * Returns a var variable with the input value.
      *
      * @param[in] rv A row vector with automatic differentiation variables
      * @return A row vector with automatic differentiation variables
