@@ -11,7 +11,7 @@ namespace stan {
       class inv_cloglog_vari : public op_v_vari {
       public:
         explicit inv_cloglog_vari(vari* avi) :
-          op_v_vari(stan::math::inv_cloglog(avi->val_), avi) {
+          op_v_vari(inv_cloglog(avi->val_), avi) {
         }
         void chain() {
           avi_->adj_ += adj_ * std::exp(avi_->val_ - std::exp(avi_->val_));
@@ -23,7 +23,7 @@ namespace stan {
      * Return the inverse complementary log-log function applied
      * specified variable (stan).
      *
-     * See stan::math::inv_cloglog() for the double-based version.
+     * See inv_cloglog() for the double-based version.
      *
      * The derivative is given by
      *
@@ -33,7 +33,7 @@ namespace stan {
      * @return The inverse complementary log-log of the specified
      * argument.
      */
-    inline var inv_cloglog(const stan::math::var& a) {
+    inline var inv_cloglog(const var& a) {
       return var(new inv_cloglog_vari(a.vi_));
     }
 
