@@ -12,7 +12,7 @@ namespace stan {
       class log1p_exp_v_vari : public op_v_vari {
       public:
         explicit log1p_exp_v_vari(vari* avi) :
-          op_v_vari(stan::math::log1p_exp(avi->val_),
+          op_v_vari(log1p_exp(avi->val_),
                     avi) {
         }
         void chain() {
@@ -25,7 +25,7 @@ namespace stan {
      * Return the log of 1 plus the exponential of the specified
      * variable.
      */
-    inline var log1p_exp(const stan::math::var& a) {
+    inline var log1p_exp(const var& a) {
       return var(new log1p_exp_v_vari(a.vi_));
     }
 
